@@ -5,4 +5,4 @@ require(DGEobj)
 require(GenomicRanges)
 
 t_obj <- readRDS(system.file("exampleObj.RDS", package = "DGEobj", mustWork = TRUE))
-t_dim <- c(1000, 48)
+t_dim <- dim(t_obj)
